@@ -5,6 +5,7 @@
 
 import os
 import wx
+import os, sys, subprocess
 from jes4py import Config
 
 def pickAFile():
@@ -13,22 +14,18 @@ def pickAFile():
        will be None.
 
     Returns:
-        the file file name of the picked file or None"""
-    app = wx.App()
-
-    frame = wx.Frame(None, -1, 'PickAFile')
-    frame.SetSize(0,0,200,50)
-
+        the file file name of the picked file or None
+    """
     # Create open file dialog
     directory = Config.getConfigVal('CONFIG_SESSION_PATH')
-    openFileDialog = wx.FileDialog(frame, "Pick A File", directory, "", "", 
-        wx.FD_OPEN | wx.FD_FILE_MUST_EXIST)
-    if openFileDialog.ShowModal() == wx.ID_CANCEL:
+    scriptpath = os.path.join(Config.getConfigVal("CONFIG_JES4PY_PATH"),
+            'filePicker.py')
+    path = subprocess.check_output([sys.executable, scriptpath, 'file',
+            directory]).decode()
+    if path == '':
         return None
     else:
-        path = openFileDialog.GetPath()
-        Config.setConfigVal('CONFIG_SESSION_PATH',os.path.dirname(path))
-        openFileDialog.Destroy()
+        Config.setConfigVal('CONFIG_SESSION_PATH', os.path.dirname(path))
         return path
 
 def pickADirectory():
@@ -36,22 +33,18 @@ def pickADirectory():
        path as a string.
 
     Returns:
-        the full directory path"""
-    app = wx.App()
-
-    frame = wx.Frame(None, -1, 'pickADirectory')
-    frame.SetSize(0,0,200,50)
-
+        the full directory path
+    """
     # Create open file dialog
     directory = Config.getConfigVal('CONFIG_SESSION_PATH')
-    openDirDialog = wx.DirDialog(frame, "Pick A Folder", directory,
-        wx.DD_DEFAULT_STYLE | wx.DD_DIR_MUST_EXIST)
-    if openDirDialog.ShowModal() == wx.ID_CANCEL:
+    scriptpath = os.path.join(Config.getConfigVal("CONFIG_JES4PY_PATH"),
+            'filePicker.py')
+    path = subprocess.check_output([sys.executable, scriptpath, 'folder',
+            directory]).decode()
+    if path == '':
         return None
     else:
-        path = openDirDialog.GetPath()
-        openDirDialog.Destroy()
-        Config.setConfigVal('CONFIG_SESSION_PATH',path)
+        Config.setConfigVal('CONFIG_SESSION_PATH', path)
         return path
 
 def getMediaPath(fileName):
